==> aliyun-python-sdk-ens-3.0.11.tar.gz: aliyun-python-sdk-ens-3.0.11/aliyunsdkens/request/v20171110/AssociateEnsEipAddressRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class AssociateEnsEipAddressRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'AssociateEnsEipAddress','ens')
		self.set_method('POST')

	def get_AllocationId(self): # String
		return self.get_query_params().get('AllocationId')

	def set_AllocationId(self, AllocationId):  # String
		self.add_query_param('AllocationId', AllocationId)
	def get_InstanceType(self): # String
		return self.get_query_params().get('InstanceType')

	def set_InstanceType(self, InstanceType):  # String
		self.add_query_param('InstanceType', InstanceType)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)

==> aliyun-python-sdk-ens-3.0.14.tar.gz: aliyun-python-sdk-ens-3.0.14/aliyunsdkens/request/v20171110/AssociateEnsEipAddressRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class AssociateEnsEipAddressRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'AssociateEnsEipAddress','ens')
		self.set_method('POST')

	def get_Standby(self): # Boolean
		return self.get_query_params().get('Standby')

	def set_Standby(self, Standby):  # Boolean
		self.add_query_param('Standby', Standby)
	def get_AllocationId(self): # String
		return self.get_query_params().get('AllocationId')

	def set_AllocationId(self, AllocationId):  # String
		self.add_query_param('AllocationId', AllocationId)
	def get_InstanceType(self): # String
		return self.get_query_params().get('InstanceType')

	def set_InstanceType(self, InstanceType):  # String
		self.add_query_param('InstanceType', InstanceType)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
